#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 generic-data
version:              1.1.0.2
visibility:           public
id:                   generic-data-1.1.0.2-CcRRzfLnt1DIgARvBEEEsM
key:                  generic-data-1.1.0.2-CcRRzfLnt1DIgARvBEEEsM
license:              MIT
copyright:            2018-2020 Li-yao Xia
maintainer:           lysxia@gmail.com
author:               Li-yao Xia
homepage:             https://github.com/Lysxia/generic-data#readme
synopsis:             Deriving instances with GHC.Generics and related utilities
description:
    Generic implementations of standard type classes.
    Operations on generic representations to help using "GHC.Generics".
    See README.

category:             Generics
abi:                  58797c296e1add2a4dff06efcb0375ca
exposed:              True
exposed-modules:
    Generic.Data Generic.Data.Internal.Compat
    Generic.Data.Internal.Data Generic.Data.Internal.Enum
    Generic.Data.Internal.Error Generic.Data.Internal.Functions
    Generic.Data.Internal.Generically Generic.Data.Internal.Meta
    Generic.Data.Internal.Microsurgery Generic.Data.Internal.Newtype
    Generic.Data.Internal.Prelude Generic.Data.Internal.Read
    Generic.Data.Internal.Resolvers Generic.Data.Internal.Show
    Generic.Data.Internal.Traversable Generic.Data.Internal.Utils
    Generic.Data.Microsurgery Generic.Data.Orphans Generic.Data.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/generic-data-1.1.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/generic-data-1.1.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/generic-data-1.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-generic-data
hs-libraries:         HSgeneric-data-1.1.0.2-CcRRzfLnt1DIgARvBEEEsM
depends:
    ap-normalize-0.1.0.1-6Z6VBwZ59hMB7oPb9nKOuv base-4.18.2.1
    base-orphans-0.9.4-FAAYyabEtHd4V101uL8YUf ghc-boot-th-9.6.6
    show-combinators-0.2.0.0-8mcquj5XLUT8kVqwDvrwi2

haddock-interfaces:
    /usr/share/doc/haskell-generic-data/html/generic-data.haddock

haddock-html:         /usr/share/doc/haskell-generic-data/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

